@@ -4,6 +4,10 @@ import time
 import os
 import sys
 import json
+import urllib
+import urllib3
+from urllib.parse import urljoin
+
 from vessel.steps import VaultInitStep, VaultSaveSecretsStep, GenerateKeysStep, \
   RegisterStep, VaultUnsealStep, GenerateYamlStep, DeployAgentStep, DeploySentinelStep
 from vessel.pipeline import Pipeline, Payload
@@ -12,8 +16,8 @@ from vessel.version import VERSION
 import kubernetes
 from kubernetes.client.rest import ApiException
 
-LATEST_AGENT="1.2"
-LATEST_SENTINEL="1.2"
+LATEST_AGENT="1.0"
+LATEST_SENTINEL="1.1.1"
 
 def start(msg):
   click.echo(f"\n> {msg}...")
@@ -150,51 +154,81 @@ def deploy(ctx, token, dry):
     if ctx.obj['DEBUG']:
       raise e
 
-@main.command()
-@click.pass_context
-@click.argument('token')
-@click.option('--agent-tag', default='latest', help="Set image tag for agent deployment")
-@click.option('--sentinel-tag', default='latest', help="Set image tag for sentinel deployment")
-def update(ctx, token, sentinel_tag, agent_tag):
-  """
-  Updates agent and sentinel deployments
-  """
-  agent_deployment = token + '-agent'
-  namespace = 'daas'
-  click.echo('Agent deployment name is %s' % agent_deployment)
-  click.echo('Updating Sentinel and Agent...')
-
-  # init kube client
-  click.echo('Creating kubernetes client configuration...')
-  configuration = kubernetes.client.Configuration()
-  configuration.host = 'https://localhost:6443'
-  configuration.verify_ssl = False
-  # TODO: recuperare questo token da vault
-  # aprirti il os.path.expanduser(f"~/.daas/vault.json")
-  # li dentro hai username e password di vault da utente
-  # ti loggi su vault con quelle
-  # recuper il token di k8s
-  k8s_token = 'eyJhbGciOiJSUzI1NiIsImtpZCI6IiJ9.eyJpc3MiOiJrdWJlcm5ldGVzL3NlcnZpY2VhY2NvdW50Iiwia3ViZXJuZXRlcy5pby9zZXJ2aWNlYWNjb3VudC9uYW1lc3BhY2UiOiJkYWFzIiwia3ViZXJuZXRlcy5pby9zZXJ2aWNlYWNjb3VudC9zZWNyZXQubmFtZSI6ImRlZmF1bHQtdG9rZW4tZnJ0OWsiLCJrdWJlcm5ldGVzLmlvL3NlcnZpY2VhY2NvdW50L3NlcnZpY2UtYWNjb3VudC5uYW1lIjoiZGVmYXVsdCIsImt1YmVybmV0ZXMuaW8vc2VydmljZWFjY291bnQvc2VydmljZS1hY2NvdW50LnVpZCI6ImM0ZDQ0M2IyLWJmOTItNGQ0OS1iZGM5LWJiZjVlZDVkZjM5YiIsInN1YiI6InN5c3RlbTpzZXJ2aWNlYWNjb3VudDpkYWFzOmRlZmF1bHQifQ.WI5UTdoeRpv6E75rYoa7crxNzniqRRDcFeUwR-MPN7y7UM8PjhMpSkTKYafnwV6fOFb2vUDN9qSCwQHNTaKjiQwWQmk4RGfXKxmkWbp3fn8XCltahLjBVvKtr6ZwT0qXS8cL2LSWr5kKruhFzNDefZ8w515jK7zg8PAGtoMz-18sTzdYMfebLVjluPm2AqxFn0WmfDawhqi_UCV4FybUiWYtRLSv0n7SrjAK-xwfISgKamrIdz8x8mCOaQCQ5BrRZuArfJIAIHOy4XUjn5fEurbcql6DcS2aBrq7yfI6ElWG7bZuF4FlsGsntTh8kotesiQ9CbQJC1chr6kZvDACWg'
-  configuration.api_key = {"authorization": "Bearer " + k8s_token}
-  api_client = kubernetes.client.ApiClient(configuration)
-  apps = kubernetes.client.AppsV1Api(api_client)
-  
+def patch_image(component, deployment, namespace, image, kube_apps):
   try:
-    body = {
-      "spec": {
-        "template": {
-          "spec": {
-            "containers": [
-              {
-                "name": "593aedda-657e-455b-9491-f774a5006de7-agent",
-                "image": "docker-registry.oc.corp.sourcesense.com/daas/workstation-agent:" + agent_tag
-                }
-            ]
+      body = {
+        "spec": {
+          "template": {
+            "spec": {
+              "containers": [
+                {
+                  "name": deployment,
+                  "image": image
+                  }
+              ]
+            }
           }
         }
       }
-    }
-    api_response = apps.patch_namespaced_deployment(agent_deployment, namespace, body)
-    logger.debug(api_response)
+      api_response = kube_apps.patch_namespaced_deployment(deployment, namespace, body)
   except ApiException as e:
-    print("Exception when calling AppsV1Api->patch_namespaced_deployment: %s\n" % e)
\ No newline at end of file
+      print("Exception when calling AppsV1Api->patch_namespaced_deployment: %s\n" % e)
+
+
+@main.command()
+@click.pass_context
+@click.argument('token')
+@click.option('--agent-tag', default=LATEST_AGENT, help="Set image tag for agent deployment")
+@click.option('--sentinel-tag', default=LATEST_SENTINEL, help="Set image tag for sentinel deployment")
+@click.option('--vault', default='http://vault.local', help='Vault endpoint [http://vault.local]')
+def update(ctx, token, vault, sentinel_tag, agent_tag):
+  """
+  Updates agent and sentinel deployments
+  """
+  urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+  payload = Payload(token)
+
+  with open('/home/rke/.vessel/devops.json') as f:
+    devops = json.load(f)
+
+  with open(os.path.expanduser(f"~/.daas/{payload.token}/registration.json"), 'r') as f:
+    registration = json.load(f)
+
+  namespace = devops['vessel_namespace']
+  img_base = devops['images_base_url']
+  k8s_token = devops['devops_sa_token']
+  cluster_name = urllib.parse.quote(registration['cluster']['result']['name'].lower().replace(" ", "-"))
+
+  # Init kube client
+  click.echo('Creating kubernetes client configuration...')
+  configuration = kubernetes.client.Configuration()
+  configuration.host = devops['kubernetes_url']
+  configuration.verify_ssl = False
+  configuration.api_key = {"authorization": "Bearer " + k8s_token}
+  api_client = kubernetes.client.ApiClient(configuration)
+  apps = kubernetes.client.AppsV1Api(api_client)
+
+  agent_deployment = cluster_name + '-agent'
+  click.echo('Agent deployment name is %s' % agent_deployment)
+
+  sentinel_deployment = cluster_name + '-sentinel'
+  click.echo('Sentinel deployment name is %s' % sentinel_deployment)
+
+  running_agent = apps.read_namespaced_deployment(agent_deployment, namespace).spec.template.spec.containers[0].image
+  click.echo('At moment, you are running this tag image for Vessel Agent => ' + running_agent.split(":")[-1] )
+  running_sentinel = apps.read_namespaced_deployment(sentinel_deployment, namespace).spec.template.spec.containers[0].image
+  click.echo('At moment, you are running this tag image for Vessel Sentinel => ' + running_sentinel.split(":")[-1] )
+
+  if running_agent.split(":")[-1] != agent_tag:
+    click.echo('Updating Agent to tag ' + agent_tag)
+    image = urljoin(img_base, 'workstation-agent') + ':' + agent_tag
+    patch_image('Agent', agent_deployment, namespace, image, apps)
+  else:
+    click.echo('Agent is already updated')
+
+  if running_sentinel.split(":")[-1] != sentinel_tag: 
+    click.echo('Updating Sentinel to tag ' + sentinel_tag)
+    image = urljoin(img_base, 'workstation-sentinel') + ':' + sentinel_tag
+    patch_image('Sentinel', sentinel_deployment, namespace, image, apps)
+  else:
+    click.echo('Sentinel is already updated')
